pub struct PortalCooldown(pub i32);Tuple Fields
0: i32Trait Implementations
Sourceimpl Clone for PortalCooldown
impl Clone for PortalCooldown
Sourcefn clone(&self) -> PortalCooldown
fn clone(&self) -> PortalCooldown
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for PortalCooldown
impl Component for PortalCooldown
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
fn register_component_hooks(_hooks: &mut ComponentHooks)
fn register_component_hooks(_hooks: &mut ComponentHooks)
Called when registering this component, allowing mutable access to its
ComponentHooks.Sourceimpl Debug for PortalCooldown
impl Debug for PortalCooldown
Sourceimpl Default for PortalCooldown
impl Default for PortalCooldown
Sourcefn default() -> PortalCooldown
fn default() -> PortalCooldown
Returns the “default value” for a type. Read more
Sourceimpl Deref for PortalCooldown
impl Deref for PortalCooldown
Sourceimpl DerefMut for PortalCooldown
impl DerefMut for PortalCooldown
Sourceimpl PartialEq for PortalCooldown
impl PartialEq for PortalCooldown
impl Copy for PortalCooldown
impl Eq for PortalCooldown
impl StructuralPartialEq for PortalCooldown